==> ui-react-1.1.469.tgz: package/esm/Banner/Banner.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
const _excluded = ["size", "maxWidth", "actions", "Component", "style", "className", "children"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
import React from 'react';
import { classNames, style as styleMethod, useAmauiTheme } from '@amaui/style-react';
import ListItemElement from '../ListItem';
import GridElement from '../Grid';
import LineElement from '../Line';
import { staticClassName } from '../utils';
const useStyle = styleMethod(theme => ({
  root: {
    width: '100%',
    '&.amaui-ListItem-root': {
      padding: '0px'
    }
  },
  listItem: {
    margin: '0 auto'
  },
  size_small: {
    padding: `${theme.methods.space.value('md') * 0.5}px ${theme.methods.space.value('rg') * 0.75}px`
  },
  size_regular: {
    padding: `${theme.methods.space.value('md', 'px')} ${theme.methods.space.value('rg', 'px')}`
  },
  size_large: {
    padding: `${theme.methods.space.value('md') * 1.5}px ${theme.methods.space.value('rg') * 1.25}px`
  },
  // maxWidth
  maxWidth_xxs: {
    maxWidth: '320px'
  },
  maxWidth_xs: {
    maxWidth: '400px'
  },
  maxWidth_sm: {
    maxWidth: '600px'
  },
  maxWidth_rg: {
    maxWidth: '960px'
  },
  maxWidth_lg: {
    maxWidth: '1240px'
  },
  maxWidth_xl: {
    maxWidth: '1920px'
  },
  maxWidth_unset: {
    maxWidth: 'unset'
  }
}), {
  name: 'amaui-Banner'
});
const Banner = /*#__PURE__*/React.forwardRef((props_, ref) => {
  const theme = useAmauiTheme();
  const props = React.useMemo(() => _objectSpread(_objectSpread(_objectSpread({}, theme?.ui?.elements?.all?.props?.default), theme?.ui?.elements?.amauiBanner?.props?.default), props_), [props_]);
  const Line = React.useMemo(() => theme?.elements?.Line || LineElement, [theme]);
  const ListItem = React.useMemo(() => theme?.elements?.ListItem || ListItemElement, [theme]);
  const Grid = React.useMemo(() => theme?.elements?.Grid || GridElement, [theme]);
  const {
      size = 'regular',
      maxWidth,
      actions,
      Component = 'div',
      style,
      className,
      children
    } = props,
    other = _objectWithoutProperties(props, _excluded);
  const {
    classes
  } = useStyle();
  const styles = {
    root: {}
  };
  if (actions) {
    other.line = true;
    other.RootProps = {};
    other.RootProps.values = {
      md: 7
    };
    other.footer = /*#__PURE__*/React.createElement(Grid, {
      Component: Line,
      RootProps: {
        gap: 1,
        direction: 'row'
      },
      justify: "flex-end",
      align: "flex-end",
      values: {
        md: 2
      },
      offsets: {
        md: 1
      }
    }, actions);
  }
  if (!classes[`maxWidth_${maxWidth}`]) styles.root.maxWidth = maxWidth;
  return /*#__PURE__*/React.createElement(Component, {
    ref: ref,
    role: "alert",
    className: classNames([staticClassName('Banner', theme) && ['amaui-Banner-root', `amaui-Banner-size-${size}`], className, classes.root]),
    style: _objectSpread(_objectSpread({}, styles.root), style)
  }, /*#__PURE__*/React.createElement(ListItem, _extends({
    size: size,
    Component: Grid,
    RootComponent: Grid,
    PrimaryProps: {
      version: 'b2'
    },
    className: classNames([staticClassName('Banner', theme) && ['amaui-Banner-list-item'], classes.listItem, classes[`size_${size}`], classes[`maxWidth_${maxWidth}`]])
  }, other), children));
});
Banner.displayName = 'amaui-Banner';
export default Banner;

==> ui-react-1.1.846.tgz: package/esm/Banner/Banner.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
const _excluded = ["size", "maxWidth", "actions", "start", "end", "Component", "style", "className", "children"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
import React from 'react';
import { classNames, style as styleMethod, useAmauiTheme } from '@amaui/style-react';
import ListItemElement from '../ListItem';
import GridElement from '../Grid';
import LineElement from '../Line';
import { staticClassName } from '../utils';
const useStyle = styleMethod(theme => ({
  root: {
    width: '100%',
    '&.amaui-ListItem-root': {
      padding: '0px'
    }
  },
  listItem: {
    margin: '0 auto'
  },
  // maxWidth
  maxWidth_xxs: {
    maxWidth: '320px'
  },
  maxWidth_xs: {
    maxWidth: '400px'
  },
  maxWidth_sm: {
    maxWidth: '600px'
  },
  maxWidth_rg: {
    maxWidth: '960px'
  },
  maxWidth_lg: {
    maxWidth: '1240px'
  },
  maxWidth_xl: {
    maxWidth: '1920px'
  },
  maxWidth_unset: {
    maxWidth: 'unset'
  }
}), {
  name: 'amaui-Banner'
});
const Banner = /*#__PURE__*/React.forwardRef((props_, ref) => {
  const theme = useAmauiTheme();
  const props = React.useMemo(() => _objectSpread(_objectSpread(_objectSpread({}, theme?.ui?.elements?.all?.props?.default), theme?.ui?.elements?.amauiBanner?.props?.default), props_), [props_]);
  const Line = React.useMemo(() => theme?.elements?.Line || LineElement, [theme]);
  const ListItem = React.useMemo(() => theme?.elements?.ListItem || ListItemElement, [theme]);
  const Grid = React.useMemo(() => theme?.elements?.Grid || GridElement, [theme]);
  const {
      size = 'regular',
      maxWidth,
      actions,
      start,
      end,
      Component = 'div',
      style,
      className,
      children
    } = props,
    other = _objectWithoutProperties(props, _excluded);
  const {
    classes
  } = useStyle();
  const styles = {
    root: {}
  };
  if (actions) {
    other.line = true;
    other.RootProps = {};
    other.RootProps.values = {
      md: 7
    };
    other.footer = /*#__PURE__*/React.createElement(Grid, {
      Component: Line,
      RootProps: {
        gap: 1,
        direction: 'row'
      },
      justify: "flex-end",
      align: "flex-end",
      values: {
        md: 2
      },
      offsets: {
        md: 1
      }
    }, actions);
  }
  if (!classes[`maxWidth_${maxWidth}`]) styles.root.maxWidth = maxWidth;
  return /*#__PURE__*/React.createElement(Component, {
    ref: ref,
    role: "alert",
    className: classNames([staticClassName('Banner', theme) && ['amaui-Banner-root', `amaui-Banner-size-${size}`], className, classes.root]),
    style: _objectSpread(_objectSpread({}, styles.root), style)
  }, start, /*#__PURE__*/React.createElement(ListItem, _extends({
    size: size,
    Component: Grid,
    RootComponent: Grid,
    PrimaryProps: {
      version: 'b2'
    },
    className: classNames([staticClassName('Banner', theme) && ['amaui-Banner-list-item'], classes.listItem, classes[`maxWidth_${maxWidth}`]])
  }, other), children), end);
});
Banner.displayName = 'amaui-Banner';
export default Banner;
